@@ -3,7 +3,7 @@
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
    | available through the world-wide-web at the following url:           |
-   | http://www.php.net/license/3_01.txt                                  |
+   | https://www.php.net/license/3_01.txt                                 |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -52,15 +52,15 @@ U_CFUNC PHP_FUNCTION(intltz_create_time_zone)
 	size_t	 str_id_len;
 	intl_error_reset(NULL);
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS(), "s", &str_id, &str_id_len) == FAILURE) {
-		RETURN_THROWS();
-	}
+	ZEND_PARSE_PARAMETERS_START(1, 1)
+		Z_PARAM_STRING(str_id, str_id_len)
+	ZEND_PARSE_PARAMETERS_END();
 
 	UErrorCode status = UErrorCode();
 	UnicodeString id = UnicodeString();
 	if (intl_stringFromChar(id, str_id, str_id_len, &status) == FAILURE) {
 		intl_error_set(NULL, status,
-			"intltz_create_time_zone: could not convert time zone id to UTF-16", 0);
+			"could not convert time zone id to UTF-16", 0);
 		RETURN_NULL();
 	}
 
@@ -76,15 +76,14 @@ U_CFUNC PHP_FUNCTION(intltz_from_date_time_zone)
 	php_timezone_obj	*tzobj;
 	intl_error_reset(NULL);
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS(), "O",
-			&zv_timezone, php_date_get_timezone_ce()) == FAILURE) {
-		RETURN_THROWS();
-	}
+	ZEND_PARSE_PARAMETERS_START(1, 1)
+		Z_PARAM_OBJECT_OF_CLASS(zv_timezone, php_date_get_timezone_ce())
+	ZEND_PARSE_PARAMETERS_END();
 
 	tzobj = Z_PHPTIMEZONE_P(zv_timezone);
 	if (!tzobj->initialized) {
 		intl_error_set(NULL, U_ILLEGAL_ARGUMENT_ERROR,
-			"intltz_from_date_time_zone: DateTimeZone object is unconstructed",
+			"DateTimeZone object is unconstructed",
 			0);
 		RETURN_NULL();
 	}
@@ -102,9 +101,7 @@ U_CFUNC PHP_FUNCTION(intltz_create_default)
 {
 	intl_error_reset(NULL);
 
-	if (zend_parse_parameters_none() == FAILURE) {
-		return;
-	}
+	ZEND_PARSE_PARAMETERS_NONE();
 
 	TimeZone *tz = TimeZone::createDefault();
 	timezone_object_construct(tz, return_value, 1);
@@ -114,9 +111,7 @@ U_CFUNC PHP_FUNCTION(intltz_get_gmt)
 {
 	intl_error_reset(NULL);
 
-	if (zend_parse_parameters_none() == FAILURE) {
-		RETURN_THROWS();
-	}
+	ZEND_PARSE_PARAMETERS_NONE();
 
 	timezone_object_construct(TimeZone::getGMT(), return_value, 0);
 }
@@ -125,9 +120,7 @@ U_CFUNC PHP_FUNCTION(intltz_get_unknown)
 {
 	intl_error_reset(NULL);
 
-	if (zend_parse_parameters_none() == FAILURE) {
-		RETURN_THROWS();
-	}
+	ZEND_PARSE_PARAMETERS_NONE();
 
 	timezone_object_construct(&TimeZone::getUnknown(), return_value, 0);
 }
@@ -140,25 +133,26 @@ U_CFUNC PHP_FUNCTION(intltz_create_enumeration)
 
 	/* double indirection to have the zend engine destroy the new zval that
 	 * results from separation */
-	if (zend_parse_parameters(ZEND_NUM_ARGS(), "|z", &arg) == FAILURE) {
-		RETURN_THROWS();
-	}
+	ZEND_PARSE_PARAMETERS_START(0, 1)
+		Z_PARAM_OPTIONAL
+		Z_PARAM_ZVAL(arg)
+	ZEND_PARSE_PARAMETERS_END();
 
 	if (arg == NULL || Z_TYPE_P(arg) == IS_NULL) {
 		se = TimeZone::createEnumeration();
 	} else if (Z_TYPE_P(arg) == IS_LONG) {
 int_offset:
-		if (Z_LVAL_P(arg) < (zend_long)INT32_MIN ||
-				Z_LVAL_P(arg) > (zend_long)INT32_MAX) {
+		if (UNEXPECTED(Z_LVAL_P(arg) < (zend_long)INT32_MIN ||
+				Z_LVAL_P(arg) > (zend_long)INT32_MAX)) {
 			intl_error_set(NULL, U_ILLEGAL_ARGUMENT_ERROR,
-				"intltz_create_enumeration: value is out of range", 0);
+				"value is out of range", 0);
 			RETURN_FALSE;
 		} else {
 			se = TimeZone::createEnumeration((int32_t) Z_LVAL_P(arg));
 		}
 	} else if (Z_TYPE_P(arg) == IS_DOUBLE) {
 double_offset:
-		convert_to_long_ex(arg);
+		convert_to_long(arg);
 		goto int_offset;
 	} else if (Z_TYPE_P(arg) == IS_OBJECT || Z_TYPE_P(arg) == IS_STRING) {
 		zend_long lval;
@@ -180,7 +174,7 @@ double_offset:
 		se = TimeZone::createEnumeration(Z_STRVAL_P(arg));
 	} else {
 		intl_error_set(NULL, U_ILLEGAL_ARGUMENT_ERROR,
-			"intltz_create_enumeration: invalid argument type", 0);
+			"invalid argument type", 0);
 		RETURN_FALSE;
 	}
 
@@ -188,7 +182,7 @@ double_offset:
 		IntlIterator_from_StringEnumeration(se, return_value);
 	} else {
 		intl_error_set(NULL, U_ILLEGAL_ARGUMENT_ERROR,
-			"intltz_create_enumeration: error obtaining enumeration", 0);
+			"error obtaining enumeration", 0);
 		RETVAL_FALSE;
 	}
 }
@@ -199,16 +193,15 @@ U_CFUNC PHP_FUNCTION(intltz_count_equivalent_ids)
 	size_t	 str_id_len;
 	intl_error_reset(NULL);
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS(), "s",
-			&str_id, &str_id_len) == FAILURE) {
-		RETURN_THROWS();
-	}
+	ZEND_PARSE_PARAMETERS_START(1, 1)
+		Z_PARAM_STRING(str_id, str_id_len)
+	ZEND_PARSE_PARAMETERS_END();
 
 	UErrorCode status = UErrorCode();
 	UnicodeString id = UnicodeString();
 	if (intl_stringFromChar(id, str_id, str_id_len, &status) == FAILURE) {
 		intl_error_set(NULL, status,
-			"intltz_count_equivalent_ids: could not convert time zone id to UTF-16", 0);
+			"could not convert time zone id to UTF-16", 0);
 		RETURN_FALSE;
 	}
 
@@ -221,29 +214,31 @@ U_CFUNC PHP_FUNCTION(intltz_create_time_zone_id_enumeration)
 	zend_long zoneType,
 			  offset_arg;
 	char	 *region		= NULL;
-	size_t	  region_len	= 0;
+	size_t    region_len = 0;
 	int32_t	  offset,
 			 *offsetp	= NULL;
-	zend_bool arg3isnull = 1;
+	bool arg3isnull = 1;
 
 	intl_error_reset(NULL);
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS(), "l|s!l!",
-			&zoneType, &region, &region_len, &offset_arg, &arg3isnull) == FAILURE) {
-		RETURN_THROWS();
-	}
+	ZEND_PARSE_PARAMETERS_START(1, 3)
+		Z_PARAM_LONG(zoneType)
+		Z_PARAM_OPTIONAL
+		Z_PARAM_STRING_OR_NULL(region, region_len)
+		Z_PARAM_LONG_OR_NULL(offset_arg, arg3isnull)
+	ZEND_PARSE_PARAMETERS_END();
 
 	if (zoneType != UCAL_ZONE_TYPE_ANY && zoneType != UCAL_ZONE_TYPE_CANONICAL
 			&& zoneType != UCAL_ZONE_TYPE_CANONICAL_LOCATION) {
 		intl_error_set(NULL, U_ILLEGAL_ARGUMENT_ERROR,
-			"intltz_create_time_zone_id_enumeration: bad zone type", 0);
+			"bad zone type", 0);
 		RETURN_FALSE;
 	}
 
 	if (!arg3isnull) {
-		if (offset_arg < (zend_long)INT32_MIN || offset_arg > (zend_long)INT32_MAX) {
+		if (UNEXPECTED(offset_arg < (zend_long)INT32_MIN || offset_arg > (zend_long)INT32_MAX)) {
 			intl_error_set(NULL, U_ILLEGAL_ARGUMENT_ERROR,
-				"intltz_create_time_zone_id_enumeration: offset out of bounds", 0);
+				"offset out of bounds", 0);
 			RETURN_FALSE;
 		}
 		offset = (int32_t)offset_arg;
@@ -254,8 +249,7 @@ U_CFUNC PHP_FUNCTION(intltz_create_time_zone_id_enumeration)
 	UErrorCode uec = UErrorCode();
 	se = TimeZone::createTimeZoneIDEnumeration((USystemTimeZoneType)zoneType,
 		region, offsetp, uec);
-	INTL_CHECK_STATUS(uec, "intltz_create_time_zone_id_enumeration: "
-		"Error obtaining time zone id enumeration")
+	INTL_CHECK_STATUS(uec, "error obtaining time zone id enumeration")
 
 	IntlIterator_from_StringEnumeration(se, return_value);
 }
@@ -267,27 +261,28 @@ U_CFUNC PHP_FUNCTION(intltz_get_canonical_id)
 	zval	*is_systemid = NULL;
 	intl_error_reset(NULL);
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS(), "s|z",
-			&str_id, &str_id_len, &is_systemid) == FAILURE) {
-		RETURN_THROWS();
-	}
+	ZEND_PARSE_PARAMETERS_START(1, 2)
+		Z_PARAM_STRING(str_id, str_id_len)
+		Z_PARAM_OPTIONAL
+		Z_PARAM_ZVAL(is_systemid)
+	ZEND_PARSE_PARAMETERS_END();
 
 	UErrorCode status = UErrorCode();
 	UnicodeString id;
 	if (intl_stringFromChar(id, str_id, str_id_len, &status) == FAILURE) {
 		intl_error_set(NULL, status,
-			"intltz_get_canonical_id: could not convert time zone id to UTF-16", 0);
+			"could not convert time zone id to UTF-16", 0);
 		RETURN_FALSE;
 	}
 
 	UnicodeString result;
 	UBool isSystemID;
 	TimeZone::getCanonicalID(id, result, isSystemID, status);
-	INTL_CHECK_STATUS(status, "intltz_get_canonical_id: error obtaining canonical ID");
+	INTL_CHECK_STATUS(status, "error obtaining canonical ID");
 
 	zend_string *u8str =intl_convert_utf16_to_utf8(result.getBuffer(), result.length(), &status);
 	INTL_CHECK_STATUS(status,
-		"intltz_get_canonical_id: could not convert time zone id to UTF-16");
+		"could not convert time zone id to UTF-16");
 	RETVAL_NEW_STR(u8str);
 
 	if (is_systemid) { /* by-ref argument passed */
@@ -304,21 +299,20 @@ U_CFUNC PHP_FUNCTION(intltz_get_region)
 	char	 outbuf[3];
 	intl_error_reset(NULL);
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS(), "s",
-			&str_id, &str_id_len) == FAILURE) {
-		RETURN_THROWS();
-	}
+	ZEND_PARSE_PARAMETERS_START(1, 1)
+		Z_PARAM_STRING(str_id, str_id_len)
+	ZEND_PARSE_PARAMETERS_END();
 
 	UErrorCode status = UErrorCode();
 	UnicodeString id;
 	if (intl_stringFromChar(id, str_id, str_id_len, &status) == FAILURE) {
 		intl_error_set(NULL, status,
-			"intltz_get_region: could not convert time zone id to UTF-16", 0);
+			"could not convert time zone id to UTF-16", 0);
 		RETURN_FALSE;
 	}
 
 	int32_t region_len = TimeZone::getRegion(id, outbuf, sizeof(outbuf), status);
-	INTL_CHECK_STATUS(status, "intltz_get_region: Error obtaining region");
+	INTL_CHECK_STATUS(status, "error obtaining region");
 
 	RETURN_STRINGL(outbuf, region_len);
 }
@@ -327,14 +321,11 @@ U_CFUNC PHP_FUNCTION(intltz_get_tz_data_version)
 {
 	intl_error_reset(NULL);
 
-	if (zend_parse_parameters_none() == FAILURE) {
-		RETURN_THROWS();
-	}
+	ZEND_PARSE_PARAMETERS_NONE();
 
 	UErrorCode status = UErrorCode();
 	const char *res = TimeZone::getTZDataVersion(status);
-	INTL_CHECK_STATUS(status, "intltz_get_tz_data_version: "
-		"Error obtaining time zone data version");
+	INTL_CHECK_STATUS(status, "error obtaining time zone data version");
 
 	RETURN_STRING(res);
 }
@@ -346,11 +337,12 @@ U_CFUNC PHP_FUNCTION(intltz_get_equivalent_id)
 	zend_long	index;
 	intl_error_reset(NULL);
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS(), "sl", &str_id, &str_id_len, &index) == FAILURE) {
-		RETURN_THROWS();
-	}
+	ZEND_PARSE_PARAMETERS_START(2, 2)
+		Z_PARAM_STRING(str_id, str_id_len)
+		Z_PARAM_LONG(index)
+	ZEND_PARSE_PARAMETERS_END();
 
-	if (index < (zend_long)INT32_MIN || index > (zend_long)INT32_MAX) {
+	if (UNEXPECTED(index < (zend_long)INT32_MIN || index > (zend_long)INT32_MAX)) {
 		RETURN_FALSE;
 	}
 
@@ -358,7 +350,7 @@ U_CFUNC PHP_FUNCTION(intltz_get_equivalent_id)
 	UnicodeString id;
 	if (intl_stringFromChar(id, str_id, str_id_len, &status) == FAILURE) {
 		intl_error_set(NULL, status,
-			"intltz_get_equivalent_id: could not convert time zone id to UTF-16", 0);
+			"could not convert time zone id to UTF-16", 0);
 		RETURN_FALSE;
 	}
 
@@ -366,11 +358,40 @@ U_CFUNC PHP_FUNCTION(intltz_get_equivalent_id)
 	zend_string *u8str;
 
 	u8str = intl_convert_utf16_to_utf8(result.getBuffer(), result.length(), &status);
-	INTL_CHECK_STATUS(status, "intltz_get_equivalent_id: "
-		"could not convert resulting time zone id to UTF-16");
+	INTL_CHECK_STATUS(status, "could not convert resulting time zone id to UTF-16");
 	RETVAL_NEW_STR(u8str);
 }
 
+#if U_ICU_VERSION_MAJOR_NUM >= 74
+U_CFUNC PHP_FUNCTION(intltz_get_iana_id)
+{
+	char	*str_id;
+	size_t	 str_id_len;
+	intl_error_reset(NULL);
+
+	ZEND_PARSE_PARAMETERS_START(1, 1)
+		Z_PARAM_STRING(str_id, str_id_len)
+	ZEND_PARSE_PARAMETERS_END();
+
+	UErrorCode status = UErrorCode();
+	UnicodeString id;
+	if (intl_stringFromChar(id, str_id, str_id_len, &status) == FAILURE) {
+		intl_error_set(NULL, status,
+			"could not convert time zone id to UTF-16", 0);
+		RETURN_FALSE;
+	}
+
+	UnicodeString result;
+	TimeZone::getIanaID(id, result, status);
+	INTL_CHECK_STATUS(status, "error obtaining IANA ID");
+
+	zend_string *u8str = intl_convert_utf16_to_utf8(result.getBuffer(), result.length(), &status);
+	INTL_CHECK_STATUS(status,
+		"could not convert time zone id to UTF-16");
+	RETVAL_NEW_STR(u8str);
+}
+#endif
+
 U_CFUNC PHP_FUNCTION(intltz_get_id)
 {
 	TIMEZONE_METHOD_INIT_VARS;
@@ -389,7 +410,7 @@ U_CFUNC PHP_FUNCTION(intltz_get_id)
 
 	u8str = intl_convert_utf16_to_utf8(
 		id_us.getBuffer(), id_us.length(), TIMEZONE_ERROR_CODE_P(to));
-	INTL_METHOD_CHECK_STATUS(to, "intltz_get_id: Could not convert id to UTF-8");
+	INTL_METHOD_CHECK_STATUS(to, "could not convert id to UTF-8");
 
 	RETVAL_NEW_STR(u8str);
 }
@@ -411,7 +432,7 @@ U_CFUNC PHP_FUNCTION(intltz_use_daylight_time)
 U_CFUNC PHP_FUNCTION(intltz_get_offset)
 {
 	double		date;
-	zend_bool	local;
+	bool	local;
 	zval		*rawOffsetArg,
 				*dstOffsetArg;
 	int32_t		rawOffset,
@@ -419,7 +440,7 @@ U_CFUNC PHP_FUNCTION(intltz_get_offset)
 	TIMEZONE_METHOD_INIT_VARS;
 
 	if (zend_parse_method_parameters(ZEND_NUM_ARGS(), getThis(),
-			"Odbz/z/", &object, TimeZone_ce_ptr, &date, &local, &rawOffsetArg,
+			"Odbzz", &object, TimeZone_ce_ptr, &date, &local, &rawOffsetArg,
 			&dstOffsetArg) == FAILURE) {
 		RETURN_THROWS();
 	}
@@ -429,12 +450,10 @@ U_CFUNC PHP_FUNCTION(intltz_get_offset)
 	to->utimezone->getOffset((UDate) date, (UBool) local, rawOffset, dstOffset,
 		TIMEZONE_ERROR_CODE(to));
 
-	INTL_METHOD_CHECK_STATUS(to, "intltz_get_offset: error obtaining offset");
+	INTL_METHOD_CHECK_STATUS(to, "error obtaining offset");
 
-	zval_ptr_dtor(rawOffsetArg);
-	ZVAL_LONG(rawOffsetArg, rawOffset);
-	zval_ptr_dtor(dstOffsetArg);
-	ZVAL_LONG(dstOffsetArg, dstOffset);
+	ZEND_TRY_ASSIGN_REF_LONG(rawOffsetArg, rawOffset);
+	ZEND_TRY_ASSIGN_REF_LONG(dstOffsetArg, dstOffset);
 
 	RETURN_TRUE;
 }
@@ -468,14 +487,14 @@ U_CFUNC PHP_FUNCTION(intltz_has_same_rules)
 	other_to = Z_INTL_TIMEZONE_P(other_object);
 	if (other_to->utimezone == NULL) {
 		intl_errors_set(&to->err, U_ILLEGAL_ARGUMENT_ERROR,
-			"intltz_has_same_rules: The second IntlTimeZone is unconstructed", 0);
+			"The second IntlTimeZone is unconstructed", 0);
 		RETURN_FALSE;
 	}
 
 	RETURN_BOOL(to->utimezone->hasSameRules(*other_to->utimezone));
 }
 
-static const TimeZone::EDisplayType display_types[] = {
+static constexpr TimeZone::EDisplayType display_types[] = {
 	TimeZone::SHORT,				TimeZone::LONG,
 	TimeZone::SHORT_GENERIC,		TimeZone::LONG_GENERIC,
 	TimeZone::SHORT_GMT,			TimeZone::LONG_GMT,
@@ -484,7 +503,7 @@ static const TimeZone::EDisplayType display_types[] = {
 
 U_CFUNC PHP_FUNCTION(intltz_get_display_name)
 {
-	zend_bool	daylight		= 0;
+	bool	daylight		= 0;
 	zend_long	display_type	= TimeZone::LONG;
 	const char *locale_str		= NULL;
 	size_t		dummy			= 0;
@@ -503,7 +522,7 @@ U_CFUNC PHP_FUNCTION(intltz_get_display_name)
 	}
 	if (!found) {
 		intl_error_set(NULL, U_ILLEGAL_ARGUMENT_ERROR,
-			"intltz_get_display_name: wrong display type", 0);
+			"wrong display type", 0);
 		RETURN_FALSE;
 	}
 
@@ -518,8 +537,7 @@ U_CFUNC PHP_FUNCTION(intltz_get_display_name)
 		Locale::createFromName(locale_str), result);
 
 	zend_string *u8str = intl_convert_utf16_to_utf8(result.getBuffer(), result.length(), TIMEZONE_ERROR_CODE_P(to));
-	INTL_METHOD_CHECK_STATUS(to, "intltz_get_display_name: "
-		"could not convert resulting time zone id to UTF-16");
+	INTL_METHOD_CHECK_STATUS(to, "could not convert resulting time zone id to UTF-16");
 
 	RETVAL_NEW_STR(u8str);
 }
@@ -608,14 +626,14 @@ U_CFUNC PHP_FUNCTION(intltz_get_windows_id)
 	UnicodeString uID, uWinID;
 	UErrorCode error;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS(), "S", &id) == FAILURE) {
-		RETURN_THROWS();
-	}
+	ZEND_PARSE_PARAMETERS_START(1, 1)
+		Z_PARAM_STR(id)
+	ZEND_PARSE_PARAMETERS_END();
 
 	error = U_ZERO_ERROR;
 	if (intl_stringFromChar(uID, id->val, id->len, &error) == FAILURE) {
 		intl_error_set(NULL, error,
-		               "intltz_get_windows_id: could not convert time zone id to UTF-16", 0);
+		               "could not convert time zone id to UTF-16", 0);
 		RETURN_FALSE;
 	}
 
@@ -624,13 +642,13 @@ U_CFUNC PHP_FUNCTION(intltz_get_windows_id)
 	INTL_CHECK_STATUS(error, "intltz_get_windows_id: Unable to get timezone from windows ID");
 	if (uWinID.length() == 0) {
 		intl_error_set(NULL, U_ILLEGAL_ARGUMENT_ERROR,
-		               "intltz_get_windows_id: Unknown system timezone", 0);
+		               "unknown system timezone", 0);
 		RETURN_FALSE;
 	}
 
 	error = U_ZERO_ERROR;
 	winID = intl_convert_utf16_to_utf8(uWinID.getBuffer(), uWinID.length(), &error);
-	INTL_CHECK_STATUS(error, "intltz_get_windows_id: could not convert time zone id to UTF-8");
+	INTL_CHECK_STATUS(error, "could not convert time zone id to UTF-8");
 	RETURN_STR(winID);
 }
 /* }}} */
@@ -644,29 +662,31 @@ U_CFUNC PHP_FUNCTION(intltz_get_id_for_windows_id)
 	UnicodeString uWinID, uID;
 	UErrorCode error;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS(), "S|S!", &winID, &region) == FAILURE) {
-		RETURN_THROWS();
-	}
+	ZEND_PARSE_PARAMETERS_START(1, 2)
+		Z_PARAM_STR(winID)
+		Z_PARAM_OPTIONAL
+		Z_PARAM_STR_OR_NULL(region)
+	ZEND_PARSE_PARAMETERS_END();
 
 	error = U_ZERO_ERROR;
 	if (intl_stringFromChar(uWinID, winID->val, winID->len, &error) == FAILURE) {
 		intl_error_set(NULL, error,
-		               "intltz_get_id_for_windows_id: could not convert time zone id to UTF-16", 0);
+		               "could not convert time zone id to UTF-16", 0);
 		RETURN_FALSE;
 	}
 
 	error = U_ZERO_ERROR;
 	TimeZone::getIDForWindowsID(uWinID, region ? region->val : NULL, uID, error);
-	INTL_CHECK_STATUS(error, "intltz_get_id_for_windows_id: Unable to get windows ID for timezone");
+	INTL_CHECK_STATUS(error, "unable to get windows ID for timezone");
 	if (uID.length() == 0) {
 		intl_error_set(NULL, U_ILLEGAL_ARGUMENT_ERROR,
-		               "intltz_get_windows_id: Unknown windows timezone", 0);
+		               "unknown windows timezone", 0);
 		RETURN_FALSE;
 	}
 
 	error = U_ZERO_ERROR;
 	id = intl_convert_utf16_to_utf8(uID.getBuffer(), uID.length(), &error);
-	INTL_CHECK_STATUS(error, "intltz_get_id_for_windows_id: could not convert time zone id to UTF-8");
+	INTL_CHECK_STATUS(error, "could not convert time zone id to UTF-8");
 	RETURN_STR(id);
 }
 /* }}} */
